@@ -46,7 +46,7 @@ Core::~Core()
 void Core::Data_Prepare()
 {
     //Inform
-    Text=MI->Inform((size_t)-1).c_str();
+    Text=MI->Inform((size_t)-1);
 }
 
 //***************************************************************************
@@ -221,7 +221,7 @@ void Core::Menu_View_HTML ()
 //---------------------------------------------------------------------------
 void Core::Menu_View_XML ()
 {
-    MI->Option(__T("Inform"), __T("XML"));
+    MI->Option(__T("Inform"), __T("MIXML"));
     Kind=Kind_XML;
 }
 
@@ -250,14 +250,42 @@ void Core::Menu_View_MPEG7 ()
 void Core::Menu_View_EBUCore_1_5 ()
 {
     MI->Option(__T("Inform"), __T("EBUCore_1.5"));
-    Kind=Kind_EBUCore_1_4;
+    Kind=Kind_EBUCore_1_5;
 }
 
 //---------------------------------------------------------------------------
 void Core::Menu_View_EBUCore_1_6()
 {
     MI->Option(__T("Inform"), __T("EBUCore_1.6"));
-    Kind = Kind_EBUCore_1_4;
+    Kind = Kind_EBUCore_1_6;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_EBUCore_1_8_ps()
+{
+    MI->Option(__T("Inform"), __T("EBUCore_1.8_parameterSegment"));
+    Kind=Kind_EBUCore_1_8_ps;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_EBUCore_1_8_sp()
+{
+    MI->Option(__T("Inform"), __T("EBUCore_1.8_segmentParameter"));
+    Kind=Kind_EBUCore_1_8_sp;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_EBUCore_1_8_ps_json()
+{
+    MI->Option(__T("Inform"), __T("EBUCore_1.8_parameterSegment_JSON"));
+    Kind=Kind_EBUCore_1_8_ps_json;
+}
+
+//---------------------------------------------------------------------------
+void Core::Menu_View_EBUCore_1_8_sp_json()
+{
+    MI->Option(__T("Inform"), __T("EBUCore_1.8_segmentParameter_JSON"));
+    Kind=Kind_EBUCore_1_8_sp_json;
 }
 
 //---------------------------------------------------------------------------
@@ -351,6 +379,12 @@ void Core::Menu_Help_Info_Parameters ()
     Text=MI->Option(__T("Info_Parameters"));
 }
 
+//---------------------------------------------------------------------------
+void Core::Menu_Help_Info_CanHandleUrls()
+{
+    Text=MI->Option(__T("Info_CanHandleUrls"));
+}
+
 //---------------------------------------------------------------------------
 void Core::Menu_Language (const String& Language)
 {
@@ -365,7 +399,7 @@ void Core::Menu_Language (const String& Language)
 String& Core::Inform_Get ()
 {
     if (Text_Temp.empty())
-        Text=MI->Inform((size_t)-1).c_str();
+        Text=MI->Inform((size_t)-1);
     else
         Text=Text_Temp;
     return Text;
@@ -381,7 +415,7 @@ Core::kind Core::Kind_Get ()
 String Core::Inform_Get(size_t Pos, stream_t StreamKind, size_t StreamPos)
 {
     MI->Option(__T("Inform"), String());
-    return MI->Get(Pos, StreamKind, StreamPos, __T("Inform")).c_str();
+    return MI->Get(Pos, StreamKind, StreamPos, __T("Inform"));
 }
 
 // Accessors
@@ -399,7 +433,7 @@ size_t Core::Count_Get(size_t File_Pos, stream_t StreamKind, size_t StreamNumber
 String Core::Summary_Get(int File_Pos, stream_t StreamKind, size_t StreamPos)
 {
     MI->Option(__T("Inform"), __T("Summary"));
-    return MI->Get(File_Pos, StreamKind, StreamPos, __T("Inform")).c_str();
+    return MI->Get(File_Pos, StreamKind, StreamPos, __T("Inform"));
 }
 
 //---------------------------------------------------------------------------
