@@ -1,21 +1,8 @@
-// GUI of MediaInfo
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #pragma hdrstop
@@ -45,7 +32,6 @@ bool CALLBACK acmDriverEnumCallback (HACMDRIVERID hadid, DWORD dwInstance, DWORD
     HACMDRIVER  had;
     ACMDRIVERDETAILS    add;
     ACMFORMATTAGDETAILS aftd;
-    int     v;
 
     memset (&add, 0, sizeof (ACMDRIVERDETAILS));
     add.cbStruct = sizeof (ACMDRIVERDETAILS);
@@ -118,7 +104,7 @@ void Codecs_Enumerate(ZenLib::ZtringListList &Video, ZenLib::ZtringListList &Aud
 // Select directory code
 // Extracted from TBffolder by Torsten Johann (t-johann@gmx.de)
 
-_TCHAR            szInitDir[MAX_PATH];
+_TCHAR szInitDir[MAX_PATH];
 
 int __stdcall BffolderCallbackProc (HWND hwnd, UINT uMsg, LPARAM lParam, LPARAM lpData)
 {
@@ -184,7 +170,7 @@ void Debug_Header_Create(const ZenLib::Ztring &FileName, void* Handle)
     FB2.Write(Tout, Capture);
 
     //Purge
-    delete Tout;
+    delete [] Tout;
     MessageBox(Handle, Prefs->Translate(__T("Send HeaderFile")).c_str(), Prefs->Translate(__T("Header file")).c_str(), 0);
 }
 
