@@ -1,21 +1,8 @@
-// GUI of MediaInfo
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 #include "editconfigtreetext.h"
 #include "_Automated/ui_editconfigtreetext.h"
@@ -51,7 +38,7 @@ void EditConfigTreeText::fillToolBox() {
     for(;ui->toolBox->count()>0;ui->toolBox->removeItem(0));
 
     for (int streamKind=0; streamKind<(int)Stream_Max; streamKind++) {
-        if(streamKind==Stream_Chapters)
+        if(streamKind==Stream_Other)
             continue;
         QFrame* box = new QFrame();
         qDebug() << "adding " << wstring2QString(C->StreamName((stream_t)streamKind));
