@@ -113,6 +113,30 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_EBUCore_1_8_ps)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_sp)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_ps_json)
+    {
+        FN.Extension_Set(__T("json"));
+        SaveDialog1->DefaultExt=__T("json");
+        SaveDialog1->Filter=__T("JSON File|*.json");
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_sp_json)
+    {
+        FN.Extension_Set(__T("json"));
+        SaveDialog1->DefaultExt=__T("json");
+        SaveDialog1->Filter=__T("JSON File|*.json");
+    }
     else if (Export->ActivePage==Export_FIMS_1_1)
     {
         FN.Extension_Set(__T("xml"));
@@ -171,6 +195,8 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
 
     if (Info==__T("XML"))
         Export->ActivePage=Export_XML;
+    else if (Info==__T("MIXML"))
+        Export->ActivePage=Export_XML;
     else if (Info==__T("MPEG-7"))
         Export->ActivePage=Export_MPEG7;
     else if (Info==__T("PBCore_1.2"))
@@ -181,6 +207,14 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
         Export->ActivePage=Export_EBUCore_1_5;
     else if (Info==__T("EBUCore_1.6"))
         Export->ActivePage=Export_EBUCore_1_6;
+    else if (Info==__T("EBUCore_1.8_ps"))
+        Export->ActivePage=Export_EBUCore_1_8_ps;
+    else if (Info==__T("EBUCore_1.8_sp"))
+        Export->ActivePage=Export_EBUCore_1_8_sp;
+    else if (Info==__T("EBUCore_1.8_ps_json"))
+        Export->ActivePage=Export_EBUCore_1_8_ps_json;
+    else if (Info==__T("EBUCore_1.8_sp_json"))
+        Export->ActivePage=Export_EBUCore_1_8_sp_json;
     else if (Info==__T("FIMS_1.1"))
         Export->ActivePage=Export_FIMS_1_1;
     else if (Info==__T("FIMS_1.2"))
@@ -414,7 +448,7 @@ void TExportF::Export_Run()
     }
     else if (Export->ActivePage==Export_XML)
     {
-        ToExport->Option_Static(__T("Inform"), __T("XML"));
+        ToExport->Option_Static(__T("Inform"), __T("MIXML"));
         if (Export_XML_SideCar->Checked)
         {
             for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
@@ -508,6 +542,70 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_EBUCore_1_8_ps)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("EBUCore_1.8_parameterSegment"));
+		if (Export_EBUCore_1_8_ps_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".EBUCore.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_sp)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("EBUCore_1.8_segmentParameter"));
+        if (Export_EBUCore_1_8_sp_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".EBUCore.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_ps_json)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("EBUCore_1.8_parameterSegment_JSON"));
+        if (Export_EBUCore_1_8_ps_json_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".EBUCore.json"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_sp_json)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("EBUCore_1.8_segmentParameter_JSON"));
+        if (Export_EBUCore_1_8_sp_json_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".EBUCore.json"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_FIMS_1_1)
     {
         ToExport->Option_Static(__T("Inform"), __T("FIMS_1.1"));
@@ -654,6 +752,34 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_EBUCore_1_6_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_EBUCore_1_8_ps)
+    {
+        Export_EBUCore_1_8_ps_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+		Name_Choose->Visible=Export_EBUCore_1_8_ps_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_sp)
+    {
+        Export_EBUCore_1_8_sp_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_EBUCore_1_8_sp_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_ps_json)
+    {
+        Export_EBUCore_1_8_ps_json_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_EBUCore_1_8_ps_json_SideCar->Checked?false:true;;
+    }
+    else if (Export->ActivePage==Export_EBUCore_1_8_sp_json)
+    {
+        Export_EBUCore_1_8_sp_json_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_EBUCore_1_8_sp_json_SideCar->Checked?false:true;;
+    }
     else if (Export->ActivePage==Export_FIMS_1_1)
     {
         Export_FIMS_1_1_SideCarClick(Sender);
@@ -770,6 +896,30 @@ void __fastcall TExportF::Export_EBUCore_1_6_SideCarClick(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TExportF::Export_EBUCore_1_8_ps_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_EBUCore_1_8_ps_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_EBUCore_1_8_sp_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_EBUCore_1_8_sp_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_EBUCore_1_8_ps_json_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_EBUCore_1_8_ps_json_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_EBUCore_1_8_sp_json_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_EBUCore_1_8_sp_json_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
 void __fastcall TExportF::Export_FIMS_1_1_SideCarClick(TObject *Sender)
 {
     Name_Choose->Visible=Export_FIMS_1_1_SideCar->Checked?false:true;
