@@ -79,7 +79,7 @@ TCustomButton*              Donate_Current;
 
 //---------------------------------------------------------------------------
 extern const ZenLib::Char* MEDIAINFO_TITLE;
-const size_t Title_Pos=96; //TODO: Position of Title in General.csv, should shange this...
+const size_t Title_Pos=156; //TODO: Position of Title in General.csv, should shange this...
 MediaInfoList *I;
 //---------------------------------------------------------------------------
 
@@ -196,14 +196,15 @@ void __fastcall TMainF::GUI_Configure()
         #endif //MEDIAINFOGUI_PREFS_NO
     }
 
-    #ifndef MEDIAINFOGUI_UPDATE_NO
+    // Removed, no more needed
+    //#ifndef MEDIAINFOGUI_UPDATE_NO
     //Web Updates
-    if (Prefs->Config(__T("CheckUpdate"))==__T("1"))
-    {
-        WebF=new TWebF(this);
-        WebF->Execute();
-    }
-    #endif //MEDIAINFOGUI_UPDATE_NO
+    //if (Prefs->Config(__T("CheckUpdate"))==__T("1"))
+    //{
+    //    WebF=new TWebF(this);
+    //    WebF->Execute();
+    //}
+    //#endif //MEDIAINFOGUI_UPDATE_NO
 
     //Menu - View
          if (Prefs->Config(__T("Output"))==__T("Basic")) {M_View_EasyClick(NULL); M_View_Easy->Checked=true;}
@@ -212,11 +213,16 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("Text")) {M_View_TextClick(NULL); M_View_Text->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("HTML")) {M_View_HTMLClick(NULL); M_View_HTML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("XML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("MIXML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MPEG-7")) {M_View_MPEG7Click(NULL); M_View_MPEG7->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) {M_View_PBCoreClick(NULL); M_View_PBCore->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_2.0")) {M_View_PBCore2Click(NULL); M_View_PBCore2->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.5")) {M_View_EBUCore_1_5Click(NULL); M_View_EBUCore_1_5->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.6")) {M_View_EBUCore_1_6Click(NULL); M_View_EBUCore_1_6->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.8_ps")) {M_View_EBUCore_1_8_psClick(NULL); M_View_EBUCore_1_8_ps->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.8_sp")) {M_View_EBUCore_1_8_spClick(NULL); M_View_EBUCore_1_8_sp->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.8_ps_json")) {M_View_EBUCore_1_8_ps_jsonClick(NULL); M_View_EBUCore_1_8_ps_json->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("EBUCore_1.8_sp_json")) {M_View_EBUCore_1_8_sp_jsonClick(NULL); M_View_EBUCore_1_8_sp_json->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.1")) {M_View_FIMS_1_1Click(NULL); M_View_FIMS_1_1->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.2")) {M_View_FIMS_1_2Click(NULL); M_View_FIMS_1_2->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.3")) {M_View_FIMS_1_3Click(NULL); M_View_FIMS_1_3->Checked=true;}
@@ -796,7 +802,7 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
     else if (Page==Page_Custom)
     {
         if (M_View_XML->Checked)
-            I->Option_Static(__T("Inform"), __T("XML"));
+            I->Option_Static(__T("Inform"), __T("MIXML"));
         else if (M_View_MPEG7->Checked)
             I->Option_Static(__T("Inform"), __T("MPEG-7"));
         else if (M_View_PBCore->Checked)
@@ -807,6 +813,14 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("EBUCore_1.5"));
         else if (M_View_EBUCore_1_6->Checked)
             I->Option_Static(__T("Inform"), __T("EBUCore_1.6"));
+        else if (M_View_EBUCore_1_8_ps->Checked)
+            I->Option_Static(__T("Inform"), __T("EBUCore_1.8_ps"));
+        else if (M_View_EBUCore_1_8_sp->Checked)
+            I->Option_Static(__T("Inform"), __T("EBUCore_1.8_sp"));
+        else if (M_View_EBUCore_1_8_ps_json->Checked)
+            I->Option_Static(__T("Inform"), __T("EBUCore_1.8_ps_JSON"));
+        else if (M_View_EBUCore_1_8_sp_json->Checked)
+            I->Option_Static(__T("Inform"), __T("EBUCore_1.8_sp_JSON"));
         else if (M_View_FIMS_1_1->Checked)
             I->Option_Static(__T("Inform"), __T("FIMS_1.1"));
         else if (M_View_FIMS_1_2->Checked)
@@ -1093,7 +1107,7 @@ void __fastcall TMainF::M_View_XMLClick(TObject *Sender)
     //Language
     I->Option_Static(__T("Language"), __T("raw"));
 
-    Prefs->Details[Prefs_Custom].Write(__T("XML"));
+    Prefs->Details[Prefs_Custom].Write(__T("MIXML"));
     ToolBar_View_XML->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1145,6 +1159,38 @@ void __fastcall TMainF::M_View_EBUCore_1_6Click(TObject *Sender)
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_EBUCore_1_8_psClick(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_ps"));
+    ToolBar_View_EBUCore_1_8_ps->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_EBUCore_1_8_spClick(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_sp"));
+    ToolBar_View_EBUCore_1_8_sp->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_EBUCore_1_8_ps_jsonClick(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_ps_json"));
+    ToolBar_View_EBUCore_1_8_ps_json->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_EBUCore_1_8_sp_jsonClick(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_sp_json"));
+    ToolBar_View_EBUCore_1_8_sp_json->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_FIMS_1_1Click(TObject *Sender)
 {
@@ -1358,10 +1404,11 @@ void __fastcall TMainF::Page_Easy_FileChange(TObject *Sender)
                 if (Page_Easy_File->ItemIndex!=-1) //To avoid refresh on the first GUI show
                     Page_Easy_X[KindOfStream][StreamPos]->Visible=Page_Easy_X_Codec[KindOfStream][StreamPos]->Caption.Length();
                 //Web
-                Page_Easy_X_Web_Url[KindOfStream][StreamPos]=I->Get(Page_Position, (stream_t)KindOfStream, StreamPos, __T("CodecID/Url")).c_str();
-                if (Page_Easy_X_Web_Url[KindOfStream][StreamPos].empty())
-                    Page_Easy_X_Web_Url[KindOfStream][StreamPos]=I->Get(Page_Position, (stream_t)KindOfStream, StreamPos, __T("Format/Url")).c_str();
-                Page_Easy_X_Web[KindOfStream][StreamPos]->Visible=Page_Easy_X_Web_Url[KindOfStream][StreamPos].size();
+                // Disabled because links are outdated
+                //Page_Easy_X_Web_Url[KindOfStream][StreamPos]=I->Get(Page_Position, (stream_t)KindOfStream, StreamPos, __T("CodecID/Url")).c_str();
+                //if (Page_Easy_X_Web_Url[KindOfStream][StreamPos].empty())
+                //    Page_Easy_X_Web_Url[KindOfStream][StreamPos]=I->Get(Page_Position, (stream_t)KindOfStream, StreamPos, __T("Format/Url")).c_str();
+                //Page_Easy_X_Web[KindOfStream][StreamPos]->Visible=Page_Easy_X_Web_Url[KindOfStream][StreamPos].size();
             }
         }
         //List
